class EventType(object):
	SEEN = 'seen'
	CONVERSATION_STARTED = 'conversation_started'
	DELIVERED = 'delivered'
	MESSAGE = 'message'
	SUBSCRIBED = 'subscribed'
	UNSUBSCRIBED = 'unsubscribed'
	FAILED = 'failed'
	WEBHOOK = 'webhook'
